import { ZemiOpenApiSpecGenerationOptions, ZemiRoute } from "./types/core.types";
import { OpenApiDoc } from "./types/openapi.types";
/**
 * Asynchronously write data to a file.
 * @param writeFile {(path: string, data: any, options: object) => void} - A function that will write data to a file; really just a way to pass in fs.promises.writeFile.
 * @param path {string} - The path to write to.
 * @param data {any} - Any data that we want to write to a file.
 * @return {Promise<void>}
 * @type {(
 *   writeFile: (path: string, data: any, options: object) => void,
 *   path: string,
 *   data: any
 * )=> Promise<void>}
 */
export declare function asyncWriteFile(writeFile: (path: string, data: any, options: object) => void, path: string, data: any): Promise<void>;
/**
 * Generate an OpenApi JSON file that has the passed-in spec and ZemiRoutes
 * defined in it. If correctly specified, this should generate an OpenAPI
 * compliant spec. This method should write to the current dir, but can be
 * overridden via {options}; it will also return and log the generated JSON.
 *
 * Note that this is **not** an OpenApi validator.
 * @param doc {OpenApiDoc} - An OpenApi spec as an {OpenApiDoc} to be used when generating the OpenApi JSON.
 * @param routes {Array<ZemiRoute>} - An array of ZemiRoutes.
 * @param [options] {ZemiOpenApiSpecGenerationOptions} - Options to use when generating the OpenApi doc.
 * @return {OpenApiDoc} - The OpenApi JSON generated from the passed in OpenApi doc and ZemiRoutes.
 * @type{(doc: OpenApiDoc, routes:Array<ZemiRoute>, options: ZemiOpenApiSpecGenerationOptions)=> Promise<OpenApiDoc>}
 */
export default function ZemiOpenApiSpecGenerator({ doc, routes, options, }: {
    doc: OpenApiDoc;
    routes: Array<ZemiRoute>;
    options?: ZemiOpenApiSpecGenerationOptions;
}): Promise<OpenApiDoc>;
